@@ -1,4 +1,6 @@
 use crate::Result;
+use log::debug;
+use std::path::Path;
 
 #[derive(PartialEq, Debug, Default)]
 pub struct GitUrlComponents {
@@ -44,7 +46,9 @@ pub fn parse_git_url_https(http_url: &str) -> Option<GitUrlComponents> {
 }
 
 pub fn fetch_and_checkout_git_repo(repo: &git2::Repository) -> Result<()> {
-    repo.find_remote("origin")?.fetch(&["master"], None, None)?;
+    let mut fetch_options = default_fetch_options();
+    repo.find_remote("origin")?
+        .fetch(&["master"], Some(&mut fetch_options), None)?;
     repo.set_head("FETCH_HEAD")?;
     let mut opts = git2::build::CheckoutBuilder::new();
     opts.force();
@@ -52,6 +56,31 @@ pub fn fetch_and_checkout_git_repo(repo: &git2::Repository) -> Result<()> {
     Ok(())
 }
 
+/// Make a git clone with the default fetch options
+pub fn clone<P: AsRef<Path>>(
+    url: &str,
+    path: P,
+) -> std::result::Result<git2::Repository, git2::Error> {
+    debug!("Cloning {} to {}", url, path.as_ref().display());
+    let fetch_options = default_fetch_options();
+    git2::build::RepoBuilder::new()
+        .fetch_options(fetch_options)
+        .clone(url, path.as_ref())
+}
+
+/// Get the default fetch options to use when fetching or cloneing
+///
+/// Currently this just ensures that git's automatic proxy settings are used.
+pub fn default_fetch_options<'a>() -> git2::FetchOptions<'a> {
+    // Use automatic proxy configuration for the fetch
+    let mut proxy_options = git2::ProxyOptions::new();
+    proxy_options.auto();
+    let mut fetch_options = git2::FetchOptions::new();
+    fetch_options.proxy_options(proxy_options);
+
+    fetch_options
+}
+
 #[test]
 fn parse_git_url_https_test() {
     assert_eq!(
